__author__ = "Jonathan Enzinna <jonnyfunfun@gmail.com>"
__version__ = "0.0.1"

import threading


class Routine(object):
    def __init__(self, recurrence):
        self.schedule = recurrence

    def __call__(self, orig_func):
        decorator_self = self

        def wrap(*args, **kwargs):
            ev = threading.Event()

            def loop():
                while not ev.wait(decorator_self.schedule):
                    orig_func(*args, **kwargs)

            thread = threading.Thread(target=loop)
            thread.daemon = True
            thread.start()

            return ev

        return wrap


import os
from setuptools import setup

# Utility function to read the README file.  
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "routines",
    version = "0.0.1",
    author = "Jonathan Enzinna",
    author_email = "jonnyfunfun@gmail.com",
    description = ("Routines is a simple package that provides a single decorator for you to mark "
            "functions as tasks (routines) that should be executed on a regular schedule."),
    license = "GPL",
    keywords = "recurrence reoccuring routines routine tasks",
    url = "http://packages.python.org/routines",
    packages=['routines'],
    long_description=read('README'),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent"
    ],
)



